@@ -1,5 +1,5 @@
 from tf3d.pinhole_projection import pinhole_matrix, pinhole_project, pinhole_reproject
-from tf3d.rt_matrix import Rt_from_quaternion, Rt_from_axis_angle, Rt_from_offset, Rt_inverse, R_from_Rt, t_from_Rt, transform
+from tf3d.rt_matrix import Rt_from_quaternion, Rt_from_axis_angle, Rt_from_offset, Rt_inverse, R_from_Rt, t_from_Rt, transform, transform_direction
 from tf3d.chaining import chain
 
 __all__ = [
@@ -13,5 +13,6 @@ __all__ = [
     "R_from_Rt",
     "t_from_Rt",
     "transform",
+    "transform_direction",
     "chain",
 ]
